--[[
	Copyright (C) 2006-2007 Nymbia

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License along
	with this program; if not, write to the Free Software Foundation, Inc.,
	51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
]]
local L = AceLibrary("AceLocale-2.2"):new("Sniff")
Sniff = AceLibrary("AceAddon-2.0"):new("FuBarPlugin-2.0", "AceDB-2.0", "AceEvent-2.0", "AceConsole-2.0", "AceDebug-2.0")
Sniff:RegisterDB("SniffDB")
local dewdrop = AceLibrary("Dewdrop-2.0")
local tablet = AceLibrary("Tablet-2.0")
local awaitingconfirm=false
Sniff.OnMenuRequest = {
	type = 'group',
	args = {
		skipconfirm = {
			type = 'toggle',
			name = L["Skip Confirmation"],
			desc = L["Skip Confirmation"]..L[" for Querying Server"],
			get = function()
				return Sniff.db.profile.skipconfirm
			end,
			set = function(v)
				Sniff.db.profile.skipconfirm = v
			end,
			map = { [false] = "Disabled", [true] = "Enabled" }
		}
	}
}
function Sniff:OnInitialize()
	self.hasIcon = true
	self.defaultPosition = "MINIMAP"
	self.defaultMinimapPosition = 60
	self:SetIcon(true)
	CreateFrame("Frame","SniffFrame",UIParent)
	SniffFrame:SetFrameStrata("DIALOG")
	SniffFrame:SetWidth(55) 
	SniffFrame:SetHeight(24)
	CreateFrame("EditBox","SniffFrameEditBox",SniffFrame,"InputBoxTemplate")
	SniffFrameEditBox:SetFrameStrata("DIALOG")
	SniffFrameEditBox:SetWidth(55)
	SniffFrameEditBox:SetHeight(24)
	SniffFrameEditBox:SetPoint("TOPLEFT",SniffFrame, 0,0)
	SniffFrameEditBox:SetScript("OnEnterPressed", function() Sniff:Search() end)
	SniffFrameEditBox:SetScript("OnEditFocusLost", function() SniffFrame:Hide() end)
	SniffFrameEditBox:SetScript("OnCursorChanged", function() SniffTooltip:Hide() end)
	SniffFrameEditBox:SetNumeric(true)
	SniffFrameEditBox:SetMaxLetters(7)
	SniffFrameEditBox:Show()
	CreateFrame("GameTooltip","SniffTooltip",SniffFrame,"GameTooltipTemplate")
	SniffTooltip:SetWidth(1)
	SniffTooltip:SetHeight(1)
	SniffTooltip:SetPoint("TOP",SniffFrame,"BOTTOM", 0,0)
	SniffTooltip:EnableMouse(true)
	SniffTooltip:SetScript("OnMouseUp", function() Sniff:Click() end)
	SniffFrame:Hide()
	if Sniff.db.profile.skipconfirm == nil then
		Sniff.db.profile.skipconfirm = false
	end
end
function Sniff:OnDataUpdate()
	Sniff:Debug("OnDataUpdate")
end
function Sniff:OnTextUpdate()
	if self:IsTextShown() then
		self:SetText(L["Sniff"])
	end
	if not self:IsIconShown() then
		self:HideIcon()
	else
		self:SetIcon("Interface\\Icons\\Spell_Nature_GroundingTotem")
	end
end
function Sniff:OnEnable()
	Sniff:RegisterEvent("Sniff_TooltipUpdate", "Search")
end
function Sniff:OnDisable()
	Sniff:UnregisterEvent("Sniff_TooltipUpdate")
	SniffFrame:Hide()
end
function Sniff:OnTooltipUpdate()
	tablet:SetHint(L["Click!"])
end
function Sniff:OnClick()
	if SniffFrame:IsVisible() then
		SniffFrame:Hide()
		return
	end
	SniffFrame:ClearAllPoints()
	if Sniff:IsMinimapAttached() then
		SniffFrame:SetPoint("BOTTOM",FuBarPluginSniffFrameMinimapButton, 0,0)
	else
		SniffFrame:SetPoint("BOTTOM",FuBarPluginSniffFrame, 0,0)
	end
	SniffFrame:Show()
	SniffFrameEditBox:SetText(L["Item ID"])
	SniffFrameEditBox:HighlightText()
end
function Sniff:Search()
	local text = SniffFrameEditBox:GetText()
	Sniff:Debug(text)
	if tonumber(text) then
		local havedata = GetItemInfo("item:" .. text)
		if havedata or Sniff.db.profile.skipconfirm then
			SniffTooltip:SetOwner(SniffFrame, "ANCHOR_PRESERVE")
			SniffTooltip:SetHyperlink("item:" .. text)
			Sniff:Print(GetItemInfo(text))
			awaitingconfirm=false
		else
			SniffTooltip:SetOwner(SniffFrame, "ANCHOR_PRESERVE")
			SniffTooltip:ClearLines()
			SniffTooltip:AddLine(L["Item not in local data"],0,1,0)
			SniffTooltip:AddLine(L["Click to Query Server"],0,1,0)
			SniffTooltip:AddLine(L["WARNING"],1,0,0)
			SniffTooltip:AddLine(L["This may result in a disconnect"],1,0,0)
			SniffTooltip:Show()
			awaitingconfirm=true
		end
	end
end
function Sniff:Click()
	local text = SniffFrameEditBox:GetText()
	if awaitingconfirm then
		SniffTooltip:SetHyperlink("item:" .. text)
		awaitingconfirm=false
		Sniff:ScheduleEvent("Sniff_TooltipUpdate",1.5)
	else
		if IsShiftKeyDown() then
			if not ChatFrameEditBox:IsVisible() then
				ChatFrameEditBox:Show()
			end
			local _, link = GetItemInfo("item:"..text)
			ChatFrameEditBox:Insert(link)
		elseif IsControlKeyDown() then
			DressUpItem(text)
		end
	end
end
function Sniff:AtCursor()
	if SniffFrame:IsVisible() then
		SniffFrame:Hide()
	else
		local x,y = GetCursorPosition()
		x = x/UIParent:GetScale()
		y = y/UIParent:GetScale()
		SniffFrame:ClearAllPoints()
		SniffFrame:SetPoint("BOTTOMLEFT",x,y)
		SniffFrame:Show()
		SniffFrameEditBox:SetText(L["Item ID"])
		SniffFrameEditBox:HighlightText()
	end
end